@@ -27,7 +27,7 @@ from .phonenumber import PhoneNumber
 from .phonenumberutil import _extract_possible_number, _PLUS_CHARS_PATTERN
 from .phonenumberutil import normalize_digits_only, region_codes_for_country_code
 from .phonenumberutil import national_significant_number
-from .phonenumberutil import _is_number_matching_desc
+from .phonenumberutil import _is_number_matching_desc, _match_national_number
 
 
 # In these countries, if extra digits are added to an emergency number, it no longer connects
@@ -50,17 +50,6 @@ def _region_dialing_from_matches_number(numobj, region_dialing_from):
     return (region_dialing_from in region_codes)
 
 
-def _matches_national_number(national_number, number_desc, allow_prefix_match):
-    """Returns whether the given national number (a string containing only decimal digits) matches
-    the national number pattern defined in the given PhoneNumberDesc object.
-    """
-    if number_desc.national_number_pattern is None:
-        return False
-    nnp_matcher = re.compile(number_desc.national_number_pattern)
-    return (fullmatch(nnp_matcher, national_number) or
-            (allow_prefix_match and nnp_matcher.match(national_number)))
-
-
 def is_possible_short_number_for_region(short_numobj, region_dialing_from):
     """Check whether a short number is a possible number when dialled from a
     region. This provides a more lenient check than
@@ -377,14 +366,14 @@ def _matches_emergency_number_helper(number, region_code, allow_prefix_match):
     emergency_desc = metadata.emergency
     allow_prefix_match_for_region = (allow_prefix_match and
                                      (region_code not in _REGIONS_WHERE_EMERGENCY_NUMBERS_MUST_BE_EXACT))
-    return _matches_national_number(normalized_number, emergency_desc,
-                                    allow_prefix_match_for_region)
+    return _match_national_number(normalized_number, emergency_desc,
+                                  allow_prefix_match_for_region)
 
 
 def is_carrier_specific(numobj):
     """Given a valid short number, determines whether it is carrier-specific
     (however, nothing is implied about its validity).  Carrier-specific numbers
-    may connect to a different end-point, or + * not connect at all, depending
+    may connect to a different end-point, or not connect at all, depending
     on the user's carrier. If it is important that the number is valid, then
     its validity must first be checked using is_valid_short_number or
     is_valid_short_number_for_region.
@@ -402,6 +391,7 @@ def is_carrier_specific(numobj):
     return (metadata is not None and
             _matches_possible_number_and_national_number(national_number, metadata.carrier_specific))
 
+
 def is_carrier_specific_for_region(numobj, region_dialing_from):
     """Given a valid short number, determines whether it is carrier-specific when
     dialed from the given region (however, nothing is implied about its
@@ -425,9 +415,12 @@ def is_carrier_specific_for_region(numobj, region_dialing_from):
     return (metadata is not None and
             _matches_possible_number_and_national_number(national_number, metadata.carrier_specific))
 
+
 # TODO: Once we have benchmarked ShortNumberInfo, consider if it is worth
 # keeping this performance optimization.
 def _matches_possible_number_and_national_number(number, number_desc):
+    if number_desc is None:
+        return False
     if len(number_desc.possible_length) > 0 and not (len(number) in number_desc.possible_length):
         return False
-    return _matches_national_number(number, number_desc, False)
+    return _match_national_number(number, number_desc, False)
